@@ -13,7 +13,7 @@ override _build_WriteMakefile_args => sub {
 
     my $args = super();
 
-    $args->{LIBS}   = ['-lmagic'];
+    $args->{LIBS}   = '-lmagic';
     $args->{INC}    = '-I. -Ic';
     $args->{XS}     = { 'lib/File/LibMagic.xs' => 'lib/File/LibMagic.c' };
     $args->{C}      = ['lib/File/LibMagic.c'];
@@ -32,8 +32,8 @@ override _build_WriteMakefile_dump => sub {
     my $dump = super();
     $dump .= <<'EOF';
 $WriteMakefileArgs{DEFINE} = _defines();
-unshift @{ $WriteMakefileArgs{LIBS} }, _libs();
-$WriteMakefileArgs{INC} = join q{ }, _includes(), $WriteMakefileArgs{INC};
+$WriteMakefileArgs{INC}    = join q{ }, _includes(), $WriteMakefileArgs{INC};
+$WriteMakefileArgs{LIBS}   = join q{ }, _libs(), $WriteMakefileArgs{LIBS};
 
 EOF
 
@@ -41,7 +41,7 @@ EOF
 };
 
 override _build_MakeFile_PL_template => sub {
-    return super() . do { local $/; <DATA> };
+    return super() . do { local $/ = undef; <DATA> };
 };
 
 __PACKAGE__->meta->make_immutable;
@@ -57,8 +57,8 @@ use Getopt::Long;
 my @libs;
 my @includes;
 
-sub _libs     { return @libs }
-sub _includes { return @includes }
+sub _libs     { return map { '-L' . $_ } @libs }
+sub _includes { return map { '-I' . $_ } @includes }
 
 sub _defines {
     GetOptions(
@@ -67,8 +67,8 @@ sub _defines {
     );
 
     my $ac = Config::AutoConf->new(
-        extra_link_flags    => [ map { '-L' . $_ } @libs ],
-        extra_include_flags => [ map { '-I' . $_ } @includes ],
+        extra_link_flags   => [ _libs() ],
+        extra_include_dirs => [ _includes() ],
     );
 
     _check_libmagic($ac);
