@@ -9,7 +9,7 @@ use Carp;
 use Exporter;
 use XSLoader;
 
-our $VERSION = '1.09';
+our $VERSION = '1.11';
 
 XSLoader::load( __PACKAGE__, $VERSION );
 
@@ -35,10 +35,12 @@ for my $name (@Constants) {
     croak "WTF defining $name - $error"
         if defined $error;
 
-    my $sub = sub { $value };
+    my $sub = sub {$value};
 
+    ## no critic (TestingAndDebugging::ProhibitNoStrict)
     no strict 'refs';
     *{$name} = $sub;
+    ## use critic
 }
 
 our %EXPORT_TAGS = (
@@ -56,8 +58,7 @@ our %EXPORT_TAGS = (
     ]
 );
 
-$EXPORT_TAGS{"all"}
-    = [ @{ $EXPORT_TAGS{"easy"} }, @{ $EXPORT_TAGS{"complete"} } ];
+$EXPORT_TAGS{all} = [ @{ $EXPORT_TAGS{easy} }, @{ $EXPORT_TAGS{complete} } ];
 
 our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 
@@ -65,7 +66,13 @@ sub new {
     my ( $class, $magic_file ) = @_;
 
     my $m = magic_open( MAGIC_NONE() );
-    magic_load( $m, $magic_file );
+
+    if ( ref $magic_file ) {
+        magic_load( $m, join ':', @{$magic_file} );
+    }
+    else {
+        magic_load( $m, $magic_file );
+    }
 
     return bless {
         magic      => $m,
@@ -155,7 +162,7 @@ File::LibMagic - Determine MIME types of data or files using libmagic
 
 =head1 VERSION
 
-version 1.09
+version 1.11
 
 =head1 SYNOPSIS
 
@@ -221,13 +228,17 @@ Each C<File::LibMagic> object loads the magic database independently of other
 C<File::LibMagic> objects, so you may want to share a single object across
 many modules.
 
-This method takes an optional argument containing a path to the magic file. If
-the file doesn't exist this will throw an exception (but only with libmagic
-4.17+).
+This method takes an optional argument containing one or more path to the
+magic file. If the file doesn't exist this will throw an exception (but only
+with libmagic 4.17+).
 
 If you don't pass an argument, it will throw an exception if it can't find any
 magic files at all.
 
+You can pass an array reference to specify more than one file. Note that even
+if you're using a custom file, you probably I<also> want to use the standard
+file (F</usr/share/misc/magic> on my system, yours may vary).
+
 =head2 $magic->info_from_filename('path/to/file')
 
 This method returns info about the given file. The return value is a hash
@@ -433,15 +444,25 @@ Dave Rolsky <autarch@urth.org>
 
 =back
 
-=head1 CONTRIBUTOR
+=head1 CONTRIBUTORS
 
-=for stopwords Olaf Alders
+=for stopwords Mithun Ayachit Olaf Alders
+
+=over 4
+
+=item *
+
+Mithun Ayachit <mayachit@amfam.com>
+
+=item *
 
 Olaf Alders <olaf@wundersolutions.com>
 
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Andreas Fitzner, Michael Hendricks, and Dave Rolsky.
+This software is copyright (c) 2015 by Andreas Fitzner, Michael Hendricks, and Dave Rolsky.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
